@@ -1,7 +1,9 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2017,2018,2019,2020,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2017,2018,2019,2020,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2023 Andrius Štikonas <andrius@stikonas.eu>
+# Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
 #
 # This file is part of GNU Mes.
 #
@@ -46,6 +48,7 @@ lib/tests/scaffold/13-if-neq.c
 lib/tests/scaffold/14-if-goto.c
 lib/tests/scaffold/15-if-not-f.c
 lib/tests/scaffold/16-if-t.c
+lib/tests/scaffold/16-cast.c
 lib/tests/scaffold/17-compare-char.c
 lib/tests/scaffold/17-compare-ge.c
 lib/tests/scaffold/17-compare-gt.c
@@ -63,6 +66,7 @@ lib/tests/scaffold/17-compare-or.c
 lib/tests/scaffold/17-compare-and-or.c
 lib/tests/scaffold/17-compare-assign.c
 lib/tests/scaffold/17-compare-call.c
+lib/tests/scaffold/17-compare-rotated.c
 lib/tests/scaffold/18-assign-shadow.c
 lib/tests/scaffold/20-while.c
 lib/tests/scaffold/21-char-array-simple.c
@@ -97,6 +101,7 @@ lib/tests/scaffold/43-for-do-while.c
 lib/tests/scaffold/44-switch.c
 lib/tests/scaffold/44-switch-fallthrough.c
 lib/tests/scaffold/44-switch-body-fallthrough.c
+lib/tests/scaffold/44-switch-body-fallthrough-not-default.c
 lib/tests/scaffold/45-void-call.c
 lib/tests/scaffold/46-function-static.c
 lib/tests/scaffold/47-function-expression.c
@@ -132,6 +137,8 @@ lib/tests/scaffold/63-struct-cell.c
 lib/tests/scaffold/64-make-cell.c
 lib/tests/scaffold/65-read.c
 lib/tests/scaffold/66-local-char-array.c
+lib/tests/scaffold/67-m1-overflow-check.c
+lib/tests/scaffold/68-truncate-shift.c
 "
 
 tcc_tests="
@@ -190,6 +197,7 @@ lib/tests/scaffold/7u-inc-byte-word.c
 lib/tests/scaffold/7u-struct-func.c
 lib/tests/scaffold/7u-struct-size10.c
 lib/tests/scaffold/7u-vstack.c
+lib/tests/scaffold/7v-struct-initialize-zeroes.c
 lib/tests/scaffold/70-array-in-struct-init.c
 lib/tests/scaffold/70-struct-short-enum-init.c
 lib/tests/scaffold/70-struct-post.c
@@ -244,8 +252,6 @@ if test $compiler = mescc; then
     xfail_tests="$xfail_tests
 lib/tests/scaffold/17-compare-unsigned-char-le.c
 lib/tests/scaffold/17-compare-unsigned-short-le.c
-lib/tests/scaffold/66-local-char-array.c
-lib/tests/scaffold/72-typedef-struct-def-local.c
 lib/tests/scaffold/70-ternary-arithmetic-argument.c
 lib/tests/mes/90-abtod.c
 lib/tests/mes/90-dtoab.c
@@ -260,7 +266,13 @@ lib/tests/scaffold/91-goto-array.c
 
     if test $mes_cpu = x86_64; then
         xfail_tests="$xfail_tests
+lib/tests/scaffold/17-compare-rotated.c
 lib/tests/scaffold/a0-call-trunc-int.c
+"
+    fi
+    if test $mes_cpu = riscv64; then
+        xfail_tests="$xfail_tests
+lib/tests/scaffold/17-compare-rotated.c
 "
     fi
 fi
@@ -290,6 +302,12 @@ lib/tests/scaffold/70-extern.c
 lib/tests/stdio/80-sscanf.c
 lib/tests/posix/90-execlp.c
 lib/tests/string/90-snprintf.c
+"
+    fi
+
+    if test $mes_cpu = riscv64; then
+        xfail_tests="$xfail_tests
+lib/tests/scaffold/70-extern.c
 "
     fi
 fi
@@ -298,7 +316,7 @@ fi
 if test -n "$bootstrap"; then
     TESTS="${TESTS-$mes_tests$tcc_tests}"
 else
-    TESTS="${TESTS-$mes_tests$tcc_test$gnu_tests}"
+    TESTS="${TESTS-$mes_tests$tcc_tests$gnu_tests}"
 fi
 
 # Allow for make check xfail_tests=lib/tests/setjmp/80-setjmp.c
