@@ -1,7 +1,8 @@
 #! /bin/sh
 
 # GNU Mes --- Maxwell Equations of Software
-# Copyright © 2018,2019,2021,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2018,2019,2021,2022,2023 Janneke Nieuwenhuizen <janneke@gnu.org>
+# Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
 #
 # This file is part of GNU Mes.
 #
@@ -20,7 +21,7 @@
 
 set -e
 
-VERSION=0.24.2
+VERSION=0.25
 srcdir=${srcdir-$(dirname $0)}
 srcdest=
 if test "$srcdir" != "."; then
@@ -99,13 +100,6 @@ else
     GUILE_EFFECTIVE_VERSION=${GUILE_EFFECTIVE_VERSION-$(guile -c '(display (effective-version))')}
 fi
 
-numbered_arch=false
-mes_tools=named
-if ( $HEX2 --help 2>&1 ) | grep -q "\-\-Architecture 12345"; then
-    numbered_arch=true
-    mes_tools=numbered
-fi
-
 bindir=$(eval echo ${bindir-$prefix/bin})
 datadir=$(eval echo ${datadir-$prefix/share})
 docdir=$(eval echo ${docdir-$datadir/doc/mes})
@@ -172,7 +166,6 @@ subst () {
     -e s,"@M2_PLANET@,$M2_PLANET,"\
     -e s,"@KAEM@,$KAEM,"\
     -e s,"@MES_FOR_BUILD@,$MES_FOR_BUILD,"\
-    -e s,"@numbered_arch@,$numbered_arch,"\
     -e s,"@SHELL@,$SHELL,"\
     $1 > $2
 }
@@ -209,7 +202,7 @@ case "$host" in
 esac
 
 case "$mes_cpu" in
-    x86_64)
+    x86_64|riscv64)
         mes_bits=64;;
     *)
         mes_bits=32;;
