@@ -1,5 +1,6 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019,2020,2021,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020,2021,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2023 Ekaitz Zarraga <ekaitz@elenq.tech>
 ;;;
 ;;; This file is part of GNU Mes.
 ;;;
@@ -31,6 +32,7 @@
   #:use-module (gnu packages commencement)
   #:use-module (gnu packages cross-base)
   #:use-module (gnu packages gcc)
+  #:use-module (gnu packages gdb)
   #:use-module (gnu packages graphviz)
   #:use-module (gnu packages guile)
   #:use-module (gnu packages man)
@@ -54,20 +56,19 @@
 (define-public mescc-tools
   (package
     (name "mescc-tools")
-    (version "1.4.0")
+    (version "1.5.0")
     (source (origin
-              (method git-fetch)
-              (uri (git-reference
-                    (url "https://git.savannah.nongnu.org/r/mescc-tools.git")
-                    (commit (string-append "Release_" version))
-                    (recursive? #t)))             ;for M2libc
-              (file-name (git-file-name name version))
+              (method url-fetch)
+              (uri (string-append
+                    "https://github.com/oriansj/mescc-tools/releases/download/"
+                    "Release_" version "/" name "-" version ".tar.gz"))
               (sha256
                (base32
-                "0z2ni2qn2np1walcaqlxz8sinzb78d4hiq9glddzf26wxc226hs4"))))
+                "1vjczlajyrbjcx9ld35vhdqbxfdwwy3axg0jray3iwnrf70qr700"))))
     (build-system gnu-build-system)
-    (supported-systems
-     '("aarch64-linux" "armhf-linux" "i686-linux" "x86_64-linux"))
+    (supported-systems '("i686-linux" "x86_64-linux"
+                         "armhf-linux" "aarch64-linux"
+                         "riscv32-linux" "riscv64-linux"))
     (native-inputs (list which))
     (arguments
      `(#:make-flags (list (string-append "PREFIX=" (assoc-ref %outputs "out"))
@@ -87,19 +88,20 @@ get_machine.")
 (define-public m2-planet
   (package
     (name "m2-planet")
-    (version "1.9.0")
+    (version "1.11.0")
     (source (origin
-              (method git-fetch)
-              (uri (git-reference
-                    (url "https://github.com/oriansj/m2-planet")
-                    (commit (string-append "Release_" version))
-                    (recursive? #t)))             ;for M2libc
-              (file-name (git-file-name name version))
+              (method url-fetch)
+              (uri (string-append
+                    "https://github.com/oriansj/M2-Planet/releases/download/"
+                    "Release_" version "/" name "-" version ".tar.gz"))
               (sha256
                (base32
-                "0cgvvq91cbxxm93k8ayyvhpaf3c2lv10qw4wyqwn3hc1qb1cfyvr"))))
+                "1c510p55amxjyvjlx9jpa30gixlgmf6mmfnaqcs46412krymwg38"))))
     (native-inputs (list mescc-tools))
     (build-system gnu-build-system)
+    (supported-systems '("i686-linux" "x86_64-linux"
+                         "armhf-linux" "aarch64-linux"
+                         "riscv32-linux" "riscv64-linux"))
     (arguments
      `(#:make-flags (list (string-append "PREFIX=" (assoc-ref %outputs "out"))
                           (string-append "CC=" ,(cc-for-target)))
@@ -183,15 +185,16 @@ extensive examples, including parsers for the Javascript and C99 languages.")
 (define-public mes
   (package
     (name "mes")
-    (version #!mes!# "0.24.1")
+    (version #!mes!# "0.24.2")
     (source (origin
               (method url-fetch)
               (uri (string-append
                     "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
               (sha256
-               (base32 #!mes!# "0246sy5zm49zw4zs87hrq1j1x74mchijh4rlj2mzlwjccha5cybs"))))
+               (base32 #!mes!# "0vp8v88zszh1imm3dvdfi3m8cywshdj7xcrsq4cgmss69s2y1nkx"))))
     (build-system gnu-build-system)
-    (supported-systems '("aarch64-linux" "armhf-linux" "i686-linux" "x86_64-linux"))
+    (supported-systems '("aarch64-linux" "armhf-linux" "i686-linux"
+                         "x86_64-linux" "riscv64-linux"))
     (propagated-inputs (list mescc-tools nyacc))
     (native-inputs
      (append
@@ -238,7 +241,7 @@ Guile.")
     (license gpl3+)))
 
 (define-public mes.git
- (let ((version #!mes!# "0.24.1")
+  (let ((version #!mes!# "0.24.2")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
@@ -247,4 +250,7 @@ Guile.")
       (version (string-append version "-" revision "." (string-take commit 7)))
       (source (local-file %source-dir
                           #:recursive? #t
-                          #:select? (git-predicate %source-dir))))))
+                          #:select? (git-predicate %source-dir)))
+      (native-inputs
+       `(("gdb" ,gdb)
+         ,@(package-native-inputs mes))))))
