@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018,2019,2021 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019,2021,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -19,21 +19,11 @@
  */
 
 #include "mes/lib-mini.h"
-
 int main (int argc, char *argv[], char *envp[]);
 
 int
 _start ()
 {
-  asm ("mov____$i8,%eax !0");
-  asm ("mov____%eax,0x32 &__stdin");
-
-  asm ("mov____$i8,%eax !1");
-  asm ("mov____%eax,0x32 &__stdout");
-
-  asm ("mov____$i8,%eax !2");
-  asm ("mov____%eax,0x32 &__stderr");
-
   asm ("mov____%ebp,%eax");
   asm ("add____$i8,%eax !4");
 
@@ -42,7 +32,6 @@ _start ()
 
   asm ("shl____$i8,%eax !0x02");
   asm ("add____%ebp,%eax");
-  asm ("mov____%eax,0x32 &environ");
   asm ("push___%eax");
 
   asm ("mov____%ebp,%eax");
@@ -54,6 +43,7 @@ _start ()
   asm ("mov____(%eax),%eax");
   asm ("push___%eax");
 
+  __init_io ();
   main ();
 
   asm ("mov____%eax,%ebx");
