@@ -1,6 +1,7 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
  * Copyright © 2018,2019,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
  *
  * This file is part of GNU Mes.
  *
@@ -20,10 +21,18 @@
 
 #include <linux/syscall.h>
 #include <arch/syscall.h>
+#include <fcntl.h>
 #include <sys/stat.h>
 
 int
 lstat (char const *file_name, struct stat *statbuf)
 {
+#if defined (SYS_lstat)
   return _sys_call2 (SYS_lstat, (long) file_name, (long) statbuf);
+#elif defined (SYS_newfstatat)
+  return _sys_call4 (SYS_newfstatat, AT_FDCWD, (long) file_name, (long) statbuf, 0);
+#else
+#error No usable stat syscall
+#endif
+  return 0;
 }
