@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -48,21 +48,5 @@ ok1:
   return 4;
 ok2:
 
-  oputs ("t: itoa (33) == \"33\"\n");
-  if (strcmp (itoa (33), "33"))
-    return 5;
-
-  oputs ("strcmp (itoa (-1), \"-1\")\n");
-  if (strcmp (itoa (-1), "-1"))
-    return 6;
-
-  oputs ("strcmp (itoa (0), \"0\")\n");
-  if (strcmp (itoa (0), "0"))
-    return 7;
-
-  oputs ("strcmp (itoa (1), \"1\")\n");
-  if (strcmp (itoa (1), "1"))
-    return 8;
-
   return 0;
 }
