@@ -1,5 +1,5 @@
 ;;; GNU Mes --- Maxwell Equations of Software
-;;; Copyright © 2016,2017,2018,2019,2020,2021,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+;;; Copyright © 2016,2017,2018,2019,2020,2021,2022,2023 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
 ;;; Copyright © 2021 W. J. van der Laan <laanwj@protonmail.com>
 ;;;
 ;;; This file is part of GNU Mes.
@@ -28,6 +28,7 @@
   #:use-module (mescc armv4 info)
   #:use-module (mescc i386 info)
   #:use-module (mescc x86_64 info)
+  #:use-module (mescc riscv64 info)
   #:use-module (mescc preprocess)
   #:use-module (mescc compile)
   #:use-module (mescc M1)
@@ -79,12 +80,8 @@
                              (else (replace-suffix input-base ".s"))))
          (infos (map (cut file->info options <>) files))
          (verbose? (count-opt options 'verbose))
-         (numbered-arch? (option-ref options 'numbered-arch? #f))
          (align (filter-map (multi-opt 'align) options))
-         (align (if (null? align) '(functions) (map string->symbol align)))
-         (align (if (not numbered-arch?) align
-                    ;; function alignment not supported by MesCC-Tools 0.5.2
-                    (filter (negate (cut eq? <> 'functions)) align))))
+         (align (if (null? align) '(functions) (map string->symbol align))))
     (when verbose?
       (format (current-error-port) "dumping: ~a\n" M1-file-name))
     (with-output-to-file* M1-file-name
@@ -173,12 +170,8 @@
          (options (acons 'compile #t options)) ; ugh
          (options (acons 'output hex2-file-name options))
          (verbose? (count-opt options 'verbose))
-         (numbered-arch? (option-ref options 'numbered-arch? #f))
          (align (filter-map (multi-opt 'align) options))
-         (align (if (null? align) '(functions) (map string->symbol align)))
-         (align (if (not numbered-arch?) align
-                    ;; function alignment not supported by MesCC-Tools 0.5.2
-                    (filter (negate (cut eq? <> 'functions)) align))))
+         (align (if (null? align) '(functions) (map string->symbol align))))
     (when verbose?
       (format (current-error-port) "dumping: ~a\n" M1-file-name))
     (with-output-to-file* M1-file-name
@@ -267,6 +260,7 @@
          (program-prefix (cond ((string-prefix? "arm-mes-" old-suffix) ".arm-mes-")
                                ((string-prefix? "x86-mes-" old-suffix) ".x86-mes-")
                                ((string-prefix? "x86_64-mes-" old-suffix) ".x86_64-mes-")
+                               ((string-prefix? "riscv64-mes-" old-suffix) ".riscv64-mes-")
                                (else "."))))
     (if (string-null? suffix)
         (if (string-null? program-prefix) (string-join base ".")
@@ -324,7 +318,9 @@
     (if machine (cond ((member arch '("x86" "x86_64")) (cond ((equal? machine "32") "x86")
                                                              ((equal? machine "64") "x86_64")))
                       ((equal? arch "arm") (cond ((equal? machine "32") "arm")
-                                                 ((equal? machine "arm") "arm"))))
+                                                 ((equal? machine "arm") "arm")))
+                      ((member arch '("riscv32" "riscv64")) (cond ((equal? machine "32") "riscv32")
+                                                                  ((equal? machine "64") "riscv64"))))
         arch)))
 
 (define (mescc:get-host options)
@@ -336,7 +332,8 @@
   (let ((arch (arch-get options)))
     (cond ((equal? arch "arm") (armv4-info))
           ((equal? arch "x86") (x86-info))
-          ((equal? arch "x86_64") (x86_64-info)))))
+          ((equal? arch "x86_64") (x86_64-info))
+          ((equal? arch "riscv64") (riscv64-info)))))
 
 (define (arch-get-defines options)
   (let* ((arch (arch-get options))
@@ -347,12 +344,16 @@
     (let ((int (sizeof "int"))
           (long (sizeof "long"))
           (long-long (sizeof "long long")))
-      (cons (cond ((equal? arch "arm")
-                   "__arm__=1")
+      (append (cond ((equal? arch "arm")
+                   '("__arm__=1"))
                   ((equal? arch "x86")
-                   "__i386__=1")
+                   '("__i386__=1"))
                   ((equal? arch "x86_64")
-                   "__x86_64__=1"))
+                   '("__x86_64__=1"))
+                  ((equal? arch "riscv32")
+                   '("__riscv=1" "__riscv_xlen=32"))
+                  ((equal? arch "riscv64")
+                   '("__riscv=1" "__riscv_xlen=64")))
             `(,(string-append "__SIZEOF_INT__=" (number->string int))
               ,(string-append "__SIZEOF_LONG__=" (number->string long))
               ,@(if (< long-long 8) '() ;C99: long long must be >= 8
@@ -362,7 +363,7 @@
   (let* ((machine (option-ref options 'machine #f))
          (arch (option-ref options 'arch #f))
          (machine (or machine arch "32")))
-    (cond ((member machine '("64" "x86_64")) "64")
+    (cond ((member machine '("64" "riscv64" "x86_64")) "64")
           ((member machine '("arm")) "32")
           (else "32"))))
 
@@ -370,16 +371,16 @@
   (let ((arch (arch-get options)))
     (cond ((equal? arch "arm") "arm.M1")
           ((equal? arch "x86") "x86.M1")
-          ((equal? arch "x86_64") "x86_64.M1"))))
+          ((equal? arch "x86_64") "x86_64.M1")
+          ((equal? arch "riscv64") "riscv64.M1"))))
 
 (define (arch-get-architecture options)
-  (let* ((arch (arch-get options))
-         (numbered-arch? (option-ref options 'numbered-arch? #f))
-        (flag (if numbered-arch? "--Architecture" "--architecture")))
-    (list flag
-          (cond ((equal? arch "arm") (if numbered-arch? "40" "armv7l"))
-                ((equal? arch "x86") (if numbered-arch? "1" "x86"))
-                ((equal? arch "x86_64") (if numbered-arch? "2" "amd64"))))))
+  (let ((arch (arch-get options)))
+    (list "--architecture"
+          (cond ((equal? arch "arm") "armv7l")
+                ((equal? arch "x86") "x86")
+                ((equal? arch "x86_64") "amd64")
+                ((equal? arch "riscv64") "riscv64")))))
 
 (define (multi-opt option-name) (lambda (o) (and (eq? (car o) option-name) (cdr o))))
 (define (count-opt options option-name)
@@ -392,17 +393,23 @@
                     (string-suffix? ".mes-E" o)
                     (string-suffix? ".arm-mes-E" o)
                     (string-suffix? ".x86-mes-E" o)
-                    (string-suffix? ".x86_64-mes-E" o)))
+                    (string-suffix? ".x86_64-mes-E" o)
+                    (string-suffix? ".riscv32-mes-E" o)
+                    (string-suffix? ".riscv64-mes-E" o)))
 (define (.s? o) (or (string-suffix? ".s" o)
                     (string-suffix? ".S" o)
                     (string-suffix? ".mes-S" o)
                     (string-suffix? ".arm-mes-S" o)
                     (string-suffix? ".x86-mes-S" o)
                     (string-suffix? ".x86_64-mes-S" o)
+                    (string-suffix? ".riscv32-mes-S" o)
+                    (string-suffix? ".riscv64-mes-S" o)
                     (string-suffix? ".M1" o)))
 (define (.o? o) (or (string-suffix? ".o" o)
                     (string-suffix? ".mes-o" o)
                     (string-suffix? ".arm-mes-o" o)
                     (string-suffix? ".x86-mes-o" o)
                     (string-suffix? ".x86_64-mes-o" o)
+                    (string-suffix? ".riscv32-mes-o" o)
+                    (string-suffix? ".riscv64-mes-o" o)
                     (string-suffix? ".hex2" o)))
