@@ -34,10 +34,6 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
-#if SYSTEM_LIBC
-#define __raise(x) -1
-#endif
-
 struct scm *
 abort_ ()                   /*:((name . "abort")) */
 {
@@ -379,12 +375,14 @@ waitpid_ (struct scm *pid, struct scm *options)
 
 #if __x86_64__
 /* Nanoseconds on 64-bit systems with POSIX timers.  */
-// CONSTANT TIME_UNITS_PER_SECOND 1000000000
+#if __M2__
+#define TIME_UNITS_PER_SECOND 1000000000
+#else
 #define TIME_UNITS_PER_SECOND 1000000000U
+#endif
 #else
 /* Milliseconds for everyone else.  */
-// CONSTANT TIME_UNITS_PER_SECOND 1000
-#define TIME_UNITS_PER_SECOND 1000U
+#define TIME_UNITS_PER_SECOND 1000
 #endif
 
 struct scm *
@@ -408,8 +406,12 @@ gettimeofday_ ()                /*:((name . "gettimeofday")) */
   return cons (make_number (time->tv_sec), make_number (time->tv_usec));
 }
 
+#if __M2__
+#define UL1000000000 1000000000
+#else
 #define UL1000000000 1000000000UL
-// CONSTANT UL1000000000 1000000000
+#endif
+
 long
 seconds_and_nanoseconds_to_long (long s, long ns)
 {
